@@ -1,9 +1,10 @@
+'use strict';
 var common = require('../common.js');
 var querystring = require('querystring');
 var v8 = require('v8');
 
 var bench = common.createBenchmark(main, {
-  type: ['noencode', 'encodemany', 'encodelast'],
+  type: ['noencode', 'encodemany', 'encodelast', 'multivalue'],
   n: [1e6],
 });
 
@@ -14,7 +15,8 @@ function main(conf) {
   var inputs = {
     noencode: 'foo=bar&baz=quux&xyzzy=thud',
     encodemany: '%66%6F%6F=bar&%62%61%7A=quux&xyzzy=%74h%75d',
-    encodelast: 'foo=bar&baz=quux&xyzzy=thu%64'
+    encodelast: 'foo=bar&baz=quux&xyzzy=thu%64',
+    multivalue: 'foo=bar&foo=baz&foo=quux&quuy=quuz'
   };
   var input = inputs[type];
 
@@ -26,8 +28,16 @@ function main(conf) {
   v8.setFlagsFromString('--allow_natives_syntax');
   eval('%OptimizeFunctionOnNextCall(querystring.parse)');
 
-  bench.start();
-  for (var i = 0; i < n; i += 1)
-    querystring.parse(input);
-  bench.end(n);
+  var i;
+  if (type !== 'multicharsep') {
+    bench.start();
+    for (i = 0; i < n; i += 1)
+      querystring.parse(input);
+    bench.end(n);
+  } else {
+    bench.start();
+    for (i = 0; i < n; i += 1)
+      querystring.parse(input, '&&&&&&&&&&');
+    bench.end(n);
+  }
 }
