@@ -835,7 +835,7 @@ function Interface(stdin, stdout, args) {
   // Run script automatically
   this.pause();
 
-  setImmediate(() => { this.run(); });
+  setImmediate(() => { this.run(() => this.resume()); });
 }
 
 
