@@ -17,7 +17,7 @@ exports.peek = peek;
 
 // remove the most idle item from the list
 function shift(list) {
-  var first = list._idlePrev;
+  const first = list._idlePrev;
   remove(first);
   return first;
 }
