@@ -142,7 +142,7 @@ CryptoStream.prototype.init = function init() {
 };
 
 
-CryptoStream.prototype._write = function write(data, encoding, cb) {
+CryptoStream.prototype._write = function _write(data, encoding, cb) {
   assert(this._pending === null);
 
   // Black-hole data
@@ -177,7 +177,7 @@ CryptoStream.prototype._write = function write(data, encoding, cb) {
     if (this.pair.encrypted._internallyPendingBytes())
       this.pair.encrypted.read(0);
 
-    // Get NPN and Server name when ready
+    // Get ALPN, NPN and Server name when ready
     this.pair.maybeInitFinished();
 
     // Whole buffer was written
@@ -223,7 +223,7 @@ CryptoStream.prototype._write = function write(data, encoding, cb) {
 };
 
 
-CryptoStream.prototype._writePending = function writePending() {
+CryptoStream.prototype._writePending = function _writePending() {
   const data = this._pending;
   const encoding = this._pendingEncoding;
   const cb = this._pendingCallback;
@@ -235,7 +235,7 @@ CryptoStream.prototype._writePending = function writePending() {
 };
 
 
-CryptoStream.prototype._read = function read(size) {
+CryptoStream.prototype._read = function _read(size) {
   // XXX: EOF?!
   if (!this.pair.ssl) return this.push(null);
 
@@ -273,7 +273,7 @@ CryptoStream.prototype._read = function read(size) {
            bytesRead < size &&
            this.pair.ssl !== null);
 
-  // Get NPN and Server name when ready
+  // Get ALPN, NPN and Server name when ready
   this.pair.maybeInitFinished();
 
   // Create new buffer if previous was filled up
@@ -729,6 +729,13 @@ function SecurePair(context, isServer, requestCert, rejectUnauthorized,
     this.npnProtocol = null;
   }
 
+  if (process.features.tls_alpn && options.ALPNProtocols) {
+    // keep reference in secureContext not to be GC-ed
+    this.ssl._secureContext.alpnBuffer = options.ALPNProtocols;
+    this.ssl.setALPNrotocols(this.ssl._secureContext.alpnBuffer);
+    this.alpnProtocol = null;
+  }
+
   /* Acts as a r/w stream to the cleartext side of the stream. */
   this.cleartext = new CleartextStream(this, options.cleartext);
 
@@ -781,6 +788,10 @@ SecurePair.prototype.maybeInitFinished = function() {
       this.npnProtocol = this.ssl.getNegotiatedProtocol();
     }
 
+    if (process.features.tls_alpn) {
+      this.alpnProtocol = this.ssl.getALPNNegotiatedProtocol();
+    }
+
     if (process.features.tls_sni) {
       this.servername = this.ssl.getServername();
     }
