@@ -552,8 +552,8 @@ fs.openSync = function(path, flags, mode) {
 fs.read = function(fd, buffer, offset, length, position, callback) {
   if (!(buffer instanceof Buffer)) {
     // legacy string interface (fd, length, position, encoding, callback)
-    var cb = arguments[4],
-        encoding = arguments[3];
+    const cb = arguments[4];
+    const encoding = arguments[3];
 
     assertEncoding(encoding);
 
@@ -697,7 +697,7 @@ fs.truncate = function(path, len, callback) {
   fs.open(path, 'r+', function(er, fd) {
     if (er) return callback(er);
     var req = new FSReqWrap();
-    req.oncomplete = function ftruncateCb(er) {
+    req.oncomplete = function oncomplete(er) {
       fs.close(fd, function(er2) {
         callback(er || er2);
       });
@@ -1098,7 +1098,7 @@ function writeAll(fd, buffer, offset, length, position, callback_) {
   fs.write(fd, buffer, offset, length, position, function(writeErr, written) {
     if (writeErr) {
       fs.close(fd, function() {
-        if (callback) callback(writeErr);
+        callback(writeErr);
       });
     } else {
       if (written === length) {
@@ -1131,7 +1131,7 @@ fs.writeFile = function(path, data, options, callback_) {
   var flag = options.flag || 'w';
   fs.open(path, flag, options.mode, function(openErr, fd) {
     if (openErr) {
-      if (callback) callback(openErr);
+      callback(openErr);
     } else {
       var buffer = (data instanceof Buffer) ? data : new Buffer('' + data,
           options.encoding || 'utf8');
@@ -1367,18 +1367,14 @@ fs.unwatchFile = function(filename, listener) {
 
 // Regexp that finds the next partion of a (partial) path
 // result is [base_with_slash, base], e.g. ['somedir/', 'somedir']
-if (isWindows) {
-  var nextPartRe = /(.*?)(?:[\/\\]+|$)/g;
-} else {
-  var nextPartRe = /(.*?)(?:[\/]+|$)/g;
-}
+const nextPartRe = isWindows ?
+  /(.*?)(?:[\/\\]+|$)/g :
+  /(.*?)(?:[\/]+|$)/g;
 
 // Regex to find the device root, including trailing slash. E.g. 'c:\\'.
-if (isWindows) {
-  var splitRootRe = /^(?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/][^\\\/]+)?[\\\/]*/;
-} else {
-  var splitRootRe = /^[\/]*/;
-}
+const splitRootRe = isWindows ?
+  /^(?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/][^\\\/]+)?[\\\/]*/ :
+  /^[\/]*/;
 
 fs.realpathSync = function realpathSync(p, cache) {
   // make p is absolute
@@ -1388,9 +1384,9 @@ fs.realpathSync = function realpathSync(p, cache) {
     return cache[p];
   }
 
-  var original = p,
-      seenLinks = {},
-      knownHard = {};
+  const original = p;
+  const seenLinks = {};
+  const knownHard = {};
 
   // current character position in p
   var pos;
@@ -1490,9 +1486,9 @@ fs.realpath = function realpath(p, cache, cb) {
     return process.nextTick(cb.bind(null, null, cache[p]));
   }
 
-  var original = p,
-      seenLinks = {},
-      knownHard = {};
+  const original = p;
+  const seenLinks = {};
+  const knownHard = {};
 
   // current character position in p
   var pos;
@@ -1763,7 +1759,7 @@ ReadStream.prototype.close = function(cb) {
       this.once('open', close);
       return;
     }
-    return process.nextTick(this.emit.bind(this, 'close'));
+    return process.nextTick(() => this.emit('close'));
   }
   this.closed = true;
   close();
@@ -1941,9 +1937,9 @@ util.inherits(SyncWriteStream, Stream);
 
 // Export
 Object.defineProperty(fs, 'SyncWriteStream', {
-    configurable: true,
-    writable: true,
-    value: SyncWriteStream
+  configurable: true,
+  writable: true,
+  value: SyncWriteStream
 });
 
 SyncWriteStream.prototype.write = function(data, arg1, arg2) {
@@ -1994,3 +1990,24 @@ SyncWriteStream.prototype.destroy = function() {
 };
 
 SyncWriteStream.prototype.destroySoon = SyncWriteStream.prototype.destroy;
+
+fs.mkdtemp = function(prefix, callback) {
+  if (typeof callback !== 'function') {
+    throw new TypeError('"callback" argument must be a function');
+  }
+
+  if (!nullCheck(prefix, callback)) {
+    return;
+  }
+
+  var req = new FSReqWrap();
+  req.oncomplete = callback;
+
+  binding.mkdtemp(prefix + 'XXXXXX', req);
+};
+
+fs.mkdtempSync = function(prefix) {
+  nullCheck(prefix);
+
+  return binding.mkdtemp(prefix + 'XXXXXX');
+};
