@@ -137,6 +137,9 @@ function Socket(options) {
   } else if (options.fd !== undefined) {
     this._handle = createHandle(options.fd);
     this._handle.open(options.fd);
+    // options.fd can be string (since it user-defined),
+    // so changing this to === would be semver-major
+    // See: https://github.com/nodejs/node/pull/11513
     if ((options.fd == 1 || options.fd == 2) &&
         (this._handle instanceof Pipe) &&
         process.platform === 'win32') {
@@ -189,7 +192,7 @@ function Socket(options) {
 }
 util.inherits(Socket, stream.Duplex);
 
-Socket.prototype._unrefTimer = function unrefTimer() {
+Socket.prototype._unrefTimer = function _unrefTimer() {
   for (var s = this; s !== null; s = s._parent)
     timers._unrefActive(s);
 };
@@ -1057,7 +1060,7 @@ function afterConnect(status, handle, req, readable, writable) {
   self._connecting = false;
   self._sockname = null;
 
-  if (status == 0) {
+  if (status === 0) {
     self.readable = readable;
     self.writable = writable;
     self._unrefTimer();
