@@ -138,7 +138,12 @@ QueryString.escape = function(str) {
     }
     // Surrogate pair
     ++i;
-    c = 0x10000 + (((c & 0x3FF) << 10) | (str.charCodeAt(i) & 0x3FF));
+    var c2;
+    if (i < str.length)
+      c2 = str.charCodeAt(i) & 0x3FF;
+    else
+      throw new URIError('URI malformed');
+    c = 0x10000 + (((c & 0x3FF) << 10) | c2);
     out += hexTable[0xF0 | (c >> 18)] +
            hexTable[0x80 | ((c >> 12) & 0x3F)] +
            hexTable[0x80 | ((c >> 6) & 0x3F)] +
@@ -209,7 +214,6 @@ QueryString.parse = QueryString.decode = function(qs, sep, eq, options) {
     return obj;
   }
 
-  var regexp = /\+/g;
   qs = qs.split(sep);
 
   var maxKeys = 1000;
@@ -230,9 +234,11 @@ QueryString.parse = QueryString.decode = function(qs, sep, eq, options) {
 
   var keys = [];
   for (var i = 0; i < len; ++i) {
-    var x = qs[i].replace(regexp, '%20'),
-        idx = x.indexOf(eq),
-        k, v;
+    // replacePlus() is used instead of a regexp because it is ~15-30% faster
+    // with v8 4.7
+    const x = replacePlus(qs[i]);
+    const idx = x.indexOf(eq);
+    var k, v;
 
     if (idx >= 0) {
       k = decodeStr(x.substring(0, idx), decode);
@@ -242,10 +248,14 @@ QueryString.parse = QueryString.decode = function(qs, sep, eq, options) {
       v = '';
     }
 
+    // Use a key array lookup instead of using hasOwnProperty(), which is slower
     if (keys.indexOf(k) === -1) {
       obj[k] = v;
       keys.push(k);
-    } else if (Array.isArray(obj[k])) {
+    } else if (obj[k] instanceof Array) {
+      // `instanceof Array` is used instead of Array.isArray() because it is
+      // ~15-20% faster with v8 4.7 and is safe to use because we are using it
+      // with values being created within this function
       obj[k].push(v);
     } else {
       obj[k] = [obj[k], v];
@@ -256,6 +266,25 @@ QueryString.parse = QueryString.decode = function(qs, sep, eq, options) {
 };
 
 
+function replacePlus(str) {
+  var ret = '';
+  var start = 0;
+  var i = -1;
+  while ((i = str.indexOf('+', i + 1)) !== -1) {
+    ret += str.slice(start, i);
+    ret += '%20';
+    start = i + 1;
+  }
+  if (start === 0)
+    return str;
+  if (start < str.length)
+    ret += str.slice(start);
+  return ret;
+}
+
+
+// v8 does not optimize functions with try-catch blocks, so we isolate them here
+// to minimize the damage
 function decodeStr(s, decoder) {
   try {
     return decoder(s);
