@@ -17,22 +17,13 @@ const EventEmitter = require('events');
 
 
 exports.createInterface = function(input, output, completer, terminal) {
-  var rl;
-  if (arguments.length === 1) {
-    rl = new Interface(input);
-  } else {
-    rl = new Interface(input, output, completer, terminal);
-  }
-  return rl;
+  return new Interface(input, output, completer, terminal);
 };
 
 
 function Interface(input, output, completer, terminal) {
   if (!(this instanceof Interface)) {
-    // call the constructor preserving original number of arguments
-    const self = Object.create(Interface.prototype);
-    Interface.apply(self, arguments);
-    return self;
+    return new Interface(input, output, completer, terminal);
   }
 
   this._sawReturn = false;
@@ -41,7 +32,7 @@ function Interface(input, output, completer, terminal) {
   EventEmitter.call(this);
   var historySize;
 
-  if (arguments.length === 1) {
+  if (input && input.input) {
     // an options object was given
     output = input.output;
     completer = input.completer;
@@ -424,7 +415,7 @@ Interface.prototype._tabComplete = function() {
 
 // this = Interface instance
 function handleGroup(self, group, width, maxColumns) {
-  if (group.length == 0) {
+  if (group.length === 0) {
     return;
   }
   var minRows = Math.ceil(group.length / maxColumns);
@@ -449,14 +440,14 @@ function handleGroup(self, group, width, maxColumns) {
 }
 
 function commonPrefix(strings) {
-  if (!strings || strings.length == 0) {
+  if (!strings || strings.length === 0) {
     return '';
   }
   var sorted = strings.slice().sort();
   var min = sorted[0];
   var max = sorted[sorted.length - 1];
   for (var i = 0, len = min.length; i < len; i++) {
-    if (min[i] != max[i]) {
+    if (min[i] !== max[i]) {
       return min.slice(0, i);
     }
   }
@@ -669,7 +660,7 @@ Interface.prototype._ttyWrite = function(s, key) {
   key = key || {};
 
   // Ignore escape key - Fixes #2876
-  if (key.name == 'escape') return;
+  if (key.name === 'escape') return;
 
   if (key.ctrl && key.shift) {
     /* Control and shift pressed */
@@ -750,7 +741,7 @@ Interface.prototype._ttyWrite = function(s, key) {
         break;
 
       case 'z':
-        if (process.platform == 'win32') break;
+        if (process.platform === 'win32') break;
         if (this.listenerCount('SIGTSTP') > 0) {
           this.emit('SIGTSTP');
         } else {
@@ -955,7 +946,7 @@ function emitKeypressEvents(stream, iface) {
   }
 
   function onNewListener(event) {
-    if (event == 'keypress') {
+    if (event === 'keypress') {
       stream.on('data', onData);
       stream.removeListener('newListener', onNewListener);
     }
