@@ -320,8 +320,8 @@ function unrefdHandle() {
 
   // Make sure we clean up if the callback is no longer a function
   // even if the timer is an interval.
-  if (!this.owner._repeat
-      || typeof this.owner._onTimeout !== 'function') {
+  if (!this.owner._repeat ||
+      typeof this.owner._onTimeout !== 'function') {
     this.owner.close();
   }
 }
