@@ -48,7 +48,7 @@ class HandleWrap : public AsyncWrap {
              uv_handle_t* handle,
              AsyncWrap::ProviderType provider,
              AsyncWrap* parent = nullptr);
-  virtual ~HandleWrap() override;
+  ~HandleWrap() override;
 
  private:
   friend class Environment;
