@@ -6,21 +6,19 @@ function serverHandler(req, res) {
   res.end('Hello World\n');
 }
 
-var http  = require('http'),
-    weak    = require('weak'),
-    done    = 0,
-    count   = 0,
-    countGC = 0,
-    todo    = 500,
-    common = require('../common'),
-    assert = require('assert'),
-    PORT = common.PORT;
+const http = require('http');
+const weak = require('weak');
+require('../common');
+const assert = require('assert');
+const todo = 500;
+let done = 0;
+let count = 0;
+let countGC = 0;
 
 console.log('We should do ' + todo + ' requests');
 
-var http = require('http');
 var server = http.createServer(serverHandler);
-server.listen(PORT, getall);
+server.listen(0, getall);
 
 
 function getall() {
@@ -38,7 +36,7 @@ function getall() {
     var req = http.get({
       hostname: 'localhost',
       pathname: '/',
-      port: PORT
+      port: server.address().port
     }, cb);
 
     count++;
@@ -52,7 +50,7 @@ for (var i = 0; i < 10; i++)
   getall();
 
 function afterGC() {
-  countGC ++;
+  countGC++;
 }
 
 setInterval(status, 1000).unref();
