@@ -4,9 +4,12 @@ require('../common');
 const assert = require('assert');
 const async_wrap = process.binding('async_wrap');
 
-
 assert.throws(function() {
   async_wrap.setupHooks(null);
+}, /first argument must be an object/);
+
+assert.throws(function() {
+  async_wrap.setupHooks({});
 }, /init callback must be a function/);
 
 assert.throws(function() {
@@ -14,7 +17,7 @@ assert.throws(function() {
 }, /init callback is not assigned to a function/);
 
 // Should not throw
-async_wrap.setupHooks(() => {});
+async_wrap.setupHooks({ init: () => {} });
 async_wrap.enable();
 
 assert.throws(function() {
