@@ -15,9 +15,9 @@ const buf = new Buffer(ab);
 assert.ok(buf instanceof Buffer);
 // For backwards compatibility of old .parent property test that if buf is not
 // a slice then .parent should be undefined.
-assert.equal(buf.parent, undefined);
-assert.equal(buf.buffer, ab);
-assert.equal(buf.length, ab.byteLength);
+assert.strictEqual(buf.parent, undefined);
+assert.strictEqual(buf.buffer, ab);
+assert.strictEqual(buf.length, ab.byteLength);
 
 
 buf.fill(0xC);
@@ -40,13 +40,13 @@ assert.equal(dv.getFloat64(8, true), 3.1415);
 
 assert.throws(function() {
   function AB() { }
-  AB.__proto__ = ArrayBuffer;
-  AB.prototype.__proto__ = ArrayBuffer.prototype;
+  Object.setPrototypeOf(AB, ArrayBuffer);
+  Object.setPrototypeOf(AB.prototype, ArrayBuffer.prototype);
   new Buffer(new AB());
 }, TypeError);
 
 // write{Double,Float}{LE,BE} with noAssert should not crash, cf. #3766
-var b = new Buffer(1);
+const b = Buffer.allocUnsafe(1);
 b.writeFloatLE(11.11, 0, true);
 b.writeFloatBE(11.11, 0, true);
 b.writeDoubleLE(11.11, 0, true);
