@@ -10,7 +10,7 @@ var net = require('net');
 if (cluster.isMaster) {
   var worker = cluster.fork();
   worker.on('exit', function(code, signal) {
-    assert.equal(code, 0, 'Worker exited with an error code');
+    assert.strictEqual(code, 0, 'Worker exited with an error code');
     assert(!signal, 'Worker exited by a signal');
     server.close();
   });
