@@ -5,7 +5,7 @@ var assert = require('assert');
 // simulate `cat readfile.js | node readfile.js`
 
 if (common.isWindows || common.isAix) {
-  console.log(`1..0 # Skipped: No /dev/stdin on ${process.platform}.`);
+  common.skip(`No /dev/stdin on ${process.platform}.`);
   return;
 }
 
