@@ -1,16 +1,16 @@
 'use strict';
-require('../common');
+const common = require('../common');
 
-process.on('uncaughtException', function() { });
+process.on('uncaughtException', common.mustCall(function() {}, 2));
 
 setTimeout(function() {
   process.nextTick(function() {
-    var c = setInterval(function() {
+    const c = setInterval(function() {
       clearInterval(c);
       throw new Error('setInterval');
-    });
+    }, 1);
   });
   setTimeout(function() {
     throw new Error('setTimeout');
-  });
+  }, 1);
 });
