@@ -1,11 +1,11 @@
 'use strict';
-var common = require('../common');
+require('../common');
 var assert = require('assert');
 var http = require('http');
 
 var options = {
   method: 'GET',
-  port: common.PORT,
+  port: undefined,
   host: '127.0.0.1',
   path: '/'
 };
@@ -14,7 +14,8 @@ var server = http.createServer(function(req, res) {
   // this space intentionally left blank
 });
 
-server.listen(options.port, options.host, function() {
+server.listen(0, options.host, function() {
+  options.port = this.address().port;
   var req = http.request(options, function(res) {
     // this space intentionally left blank
   });
