@@ -1,11 +1,12 @@
 'use strict';
 const common = require('../common');
-const assert = require('assert');
 
 if (!common.hasCrypto) {
   common.skip('missing crypto');
   return;
 }
+
+const assert = require('assert');
 const https = require('https');
 
 const fs = require('fs');
@@ -14,7 +15,7 @@ const key = fs.readFileSync(common.fixturesDir + '/keys/agent1-key.pem');
 const cert = fs.readFileSync(common.fixturesDir + '/keys/agent1-cert.pem');
 
 // number of bytes discovered empirically to trigger the bug
-const data = Buffer.allocUnsafe(1024 * 32 + 1);
+const data = Buffer.alloc(1024 * 32 + 1);
 
 httpsTest();
 
@@ -36,12 +37,11 @@ function httpsTest() {
 }
 
 
-function test(res) {
-  res.on('end', function() {
+const test = common.mustCall(function(res) {
+  res.on('end', common.mustCall(function() {
     assert.strictEqual(res._readableState.length, 0);
     assert.strictEqual(bytes, data.length);
-    console.log('ok');
-  });
+  }));
 
   // Pause and then resume on each chunk, to ensure that there will be
   // a lone byte hanging out at the very end.
@@ -49,6 +49,6 @@ function test(res) {
   res.on('data', function(chunk) {
     bytes += chunk.length;
     this.pause();
-    setTimeout(this.resume.bind(this));
+    setTimeout(this.resume.bind(this), 1);
   });
-}
+});
