@@ -1,15 +1,14 @@
 'use strict';
-var common = require('../common');
+const common = require('../common');
 var assert = require('assert');
 var net = require('net');
-var accessedProperties = false;
 
 var server = net.createServer(function(socket) {
   socket.end();
 });
 
-server.listen(common.PORT, function() {
-  var client = net.createConnection(common.PORT);
+server.listen(0, common.mustCall(function() {
+  var client = net.createConnection(this.address().port);
   server.close();
   // server connection event has not yet fired
   // client is still attempting to connect
@@ -18,11 +17,6 @@ server.listen(common.PORT, function() {
     client.remoteFamily;
     client.remotePort;
   });
-  accessedProperties = true;
   // exit now, do not wait for the client error event
   process.exit(0);
-});
-
-process.on('exit', function() {
-  assert(accessedProperties);
-});
+}));
