@@ -2,15 +2,15 @@
 require('../common');
 var assert = require('assert');
 
-var order = [],
-    exceptionHandled = false;
+const order = [];
+let exceptionHandled = false;
 
 // This nextTick function will throw an error.  It should only be called once.
 // When it throws an error, it should still get removed from the queue.
 process.nextTick(function() {
   order.push('A');
   // cause an error
-  what();
+  what(); // eslint-disable-line no-undef
 });
 
 // This nextTick function should remain in the queue when the first one
@@ -24,8 +24,7 @@ process.on('uncaughtException', function() {
   if (!exceptionHandled) {
     exceptionHandled = true;
     order.push('B');
-  }
-  else {
+  } else {
     // If we get here then the first process.nextTick got called twice
     order.push('OOPS!');
   }
