@@ -18,6 +18,6 @@ putIn.write = function(data) {
 };
 
 putIn.run([
-  'require("domain").create().on("error", function() { console.log("OK") })'
-  + '.run(function() { throw new Error("threw") })'
+  'require("domain").create().on("error", function() { console.log("OK") })' +
+  '.run(function() { throw new Error("threw") })'
 ]);
