@@ -1,9 +1,10 @@
 'use strict';
-require('../common');
+var common = require('../common');
+var path = require('path');
 var assert = require('assert');
 
 try {
-  require('../fixtures/invalid.json');
+  require(path.join(common.fixturesDir, 'invalid.json'));
 } catch (err) {
   var re = /test[\/\\]fixtures[\/\\]invalid.json: Unexpected string/;
   var i = err.message.match(re);
