@@ -17,19 +17,10 @@ var path = require('path');
   var cert = fs.readFileSync(path.join(common.fixturesDir, 'test_cert.pem'));
   var key = fs.readFileSync(path.join(common.fixturesDir, 'test_key.pem'));
 
-  var errorEmitted = false;
+  var options = {cert: cert, key: key, port: common.PORT};
+  var conn = tls.connect(options, common.fail);
 
-  process.on('exit', function() {
-    assert.ok(errorEmitted);
-  });
-
-  var conn = tls.connect({cert: cert, key: key, port: common.PORT}, function() {
-    assert.ok(false); // callback should never be executed
-  });
-
-  conn.on('error', function() {
-    errorEmitted = true;
-  });
+  conn.on('error', common.mustCall(function() {}));
 })();
 
 // SSL_accept/SSL_connect error handling
@@ -37,12 +28,6 @@ var path = require('path');
   var cert = fs.readFileSync(path.join(common.fixturesDir, 'test_cert.pem'));
   var key = fs.readFileSync(path.join(common.fixturesDir, 'test_key.pem'));
 
-  var errorEmitted = false;
-
-  process.on('exit', function() {
-    assert.ok(errorEmitted);
-  });
-
   var conn = tls.connect({
     cert: cert,
     key: key,
@@ -52,7 +37,5 @@ var path = require('path');
     assert.ok(false); // callback should never be executed
   });
 
-  conn.on('error', function() {
-    errorEmitted = true;
-  });
+  conn.on('error', common.mustCall(function() {}));
 })();
