@@ -4,8 +4,8 @@ require('../common');
 const assert = require('assert');
 const tls = require('tls');
 
-const singles = 'C=US\nST=CA\nL=SF\nO=Node.js Foundation\nOU=Node.js\nCN=ca1\n'
-  + 'emailAddress=ry@clouds.org';
+const singles = 'C=US\nST=CA\nL=SF\nO=Node.js Foundation\nOU=Node.js\n' +
+                'CN=ca1\nemailAddress=ry@clouds.org';
 const singlesOut = tls.parseCertString(singles);
 assert.deepEqual(singlesOut, {
   C: 'US',
@@ -18,7 +18,7 @@ assert.deepEqual(singlesOut, {
 });
 
 const doubles = 'OU=Domain Control Validated\nOU=PositiveSSL Wildcard\n' +
-  'CN=*.nodejs.org';
+                'CN=*.nodejs.org';
 const doublesOut = tls.parseCertString(doubles);
 assert.deepEqual(doublesOut, {
   OU: [ 'Domain Control Validated', 'PositiveSSL Wildcard' ],
