@@ -18,7 +18,7 @@ assert.strictEqual(result, 'function');
 // Test 2: vm.runInContext
 var sandbox2 = { foo: 'bar' };
 var context = vm.createContext(sandbox2);
-var result = vm.runInContext(
+result = vm.runInContext(
   'baz = foo; this.typeofProcess = typeof process; typeof Object;',
   context
 );
@@ -30,7 +30,7 @@ assert.deepEqual(sandbox2, {
 assert.strictEqual(result, 'function');
 
 // Test 3: vm.runInThisContext
-var result = vm.runInThisContext(
+result = vm.runInThisContext(
   'vmResult = "foo"; Object.prototype.toString.call(process);'
 );
 assert.strictEqual(global.vmResult, 'foo');
@@ -38,7 +38,7 @@ assert.strictEqual(result, '[object process]');
 delete global.vmResult;
 
 // Test 4: vm.runInNewContext
-var result = vm.runInNewContext(
+result = vm.runInNewContext(
   'vmResult = "foo"; typeof process;'
 );
 assert.strictEqual(global.vmResult, undefined);
