@@ -1,11 +1,11 @@
 'use strict';
 
 require('../common');
-var assert = require('assert');
+const assert = require('assert');
 
-var vm = require('vm');
+const vm = require('vm');
 
-var symbol = Symbol();
+const symbol = Symbol();
 
 function Document() {
   this[symbol] = 'foo';
@@ -15,11 +15,11 @@ Document.prototype.getSymbolValue = function() {
   return this[symbol];
 };
 
-var context = new Document();
+const context = new Document();
 vm.createContext(context);
 
-assert.equal(context.getSymbolValue(), 'foo',
+assert.strictEqual(context.getSymbolValue(), 'foo',
     'should return symbol-keyed value from the outside');
 
-assert.equal(vm.runInContext('this.getSymbolValue()', context), 'foo',
+assert.strictEqual(vm.runInContext('this.getSymbolValue()', context), 'foo',
     'should return symbol-keyed value from the inside');
