@@ -5,16 +5,16 @@ var zlib = require('zlib');
 var path = require('path');
 var fs = require('fs');
 
-var file = fs.readFileSync(path.resolve(common.fixturesDir, 'person.jpg')),
-    chunkSize = 24 * 1024,
-    opts = { level: 9, strategy: zlib.Z_DEFAULT_STRATEGY },
-    deflater = zlib.createDeflate(opts);
+const file = fs.readFileSync(path.resolve(common.fixturesDir, 'person.jpg'));
+const chunkSize = 12 * 1024;
+const opts = { level: 9, strategy: zlib.Z_DEFAULT_STRATEGY };
+const deflater = zlib.createDeflate(opts);
 
-var chunk1 = file.slice(0, chunkSize),
-    chunk2 = file.slice(chunkSize),
-    blkhdr = new Buffer([0x00, 0x48, 0x82, 0xb7, 0x7d]),
-    expected = Buffer.concat([blkhdr, chunk2]),
-    actual;
+const chunk1 = file.slice(0, chunkSize);
+const chunk2 = file.slice(chunkSize);
+const blkhdr = new Buffer([0x00, 0x5a, 0x82, 0xa5, 0x7d]);
+const expected = Buffer.concat([blkhdr, chunk2]);
+let actual;
 
 deflater.write(chunk1, function() {
   deflater.params(0, zlib.Z_DEFAULT_STRATEGY, function() {
