@@ -3,7 +3,7 @@ var common = require('../common');
 var assert = require('assert');
 
 if (!common.hasCrypto) {
-  console.log('1..0 # Skipped: missing crypto');
+  common.skip('missing crypto');
   return;
 }
 var crypto = require('crypto');
@@ -11,8 +11,8 @@ var crypto = require('crypto');
 var p = crypto.createDiffieHellman(1024).getPrime();
 
 for (var i = 0; i < 2000; i++) {
-  var a = crypto.createDiffieHellman(p),
-      b = crypto.createDiffieHellman(p);
+  const a = crypto.createDiffieHellman(p);
+  const b = crypto.createDiffieHellman(p);
 
   a.generateKeys();
   b.generateKeys();
