@@ -44,15 +44,13 @@ var timeToQuit = Date.now() + 8e3; //Test during no more than this seconds.
     if (bufPool.push(nuBuf) > 100) {
       bufPool.length = 0;
     }
-  }
-  else {
+  } else {
     throw new Error("Buffer GC'ed test -> FAIL");
   }
 
   if (Date.now() < timeToQuit) {
     process.nextTick(main);
-  }
-  else {
+  } else {
     tail.kill();
     console.log("Buffer GC'ed test -> PASS (OK)");
   }
