@@ -69,6 +69,13 @@ assert.strictEqual(threeFolder, threeIndex);
 assert.notStrictEqual(threeFolder, three);
 
 console.error('test package.json require() loading');
+assert.throws(
+  function() {
+    require('../fixtures/packages/invalid');
+  },
+  /^SyntaxError: Error parsing \S+: Unexpected token ,$/
+);
+
 assert.strictEqual(require('../fixtures/packages/main').ok, 'ok',
                    'Failed loading package');
 assert.strictEqual(require('../fixtures/packages/main-index').ok, 'ok',
@@ -90,7 +97,8 @@ console.error('test name clashes');
 var my_path = require('../fixtures/path');
 assert.ok(my_path.path_func instanceof Function);
 // this one does not exist and should throw
-assert.throws(function() { require('./utils'); });
+assert.throws(function() { require('./utils'); },
+              /^Error: Cannot find module '.\/utils'$/);
 
 var errorThrown = false;
 try {
@@ -117,7 +125,7 @@ assert.strictEqual(require('../fixtures/registerExt.hello.world').test,
                    'passed');
 
 console.error('load custom file types that return non-strings');
-require.extensions['.test'] = function(module, filename) {
+require.extensions['.test'] = function(module) {
   module.exports = {
     custom: 'passed'
   };
